#
# spec file for package python3-pep8
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python3-pep8
Version:        1.6.2
Release:        6.1
Url:            http://github.com/jcrocholl/pep8
Summary:        Python style guide checker
License:        MIT
Group:          Development/Languages/Python
Source:         http://pypi.python.org/packages/source/p/pep8/pep8-%{version}.tar.gz
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  fdupes
BuildRequires:  python3
BuildRequires:  python3-2to3
BuildRequires:  python3-devel
BuildRequires:  python3-setuptools
BuildArch:      noarch

%description
Pep8 is a tool to check your Python code against some of the style
conventions in PEP 8.

%prep
%setup -q -n pep8-%{version}
sed -i "/\#\!\/usr\/bin\/env python/d" pep8.py # Remove she-bang line

%build
python3 setup.py build

%install
python3 setup.py install --prefix=%{_prefix} --root=%{buildroot}
mv %{buildroot}%{_bindir}/pep8 %{buildroot}%{_bindir}/pep8-python%{py3_ver}
rm -rf %{buildroot}%{python3_sitelib}/__pycache__/
%fdupes %{buildroot}%{python_sitelib}

%files
%defattr(-,root,root)
%doc CHANGES.txt README.rst
%{_bindir}/pep8-python%{py3_ver}
%{python3_sitelib}/pep8.py*
%{python3_sitelib}/pep8-%{version}-py%{py3_ver}.egg-info/

%changelog
* Mon Feb 16 2015 arun@gmx.de
- update to version 1.6.2:
  * Added check for breaking around a binary operator. (Issue #197, Pull #305)
  * Restored config_file parameter in process_options(). (Issue #380)
* Mon Feb  9 2015 arun@gmx.de
- update to version 1.6.1:
  * Assign variables before referenced. (Issue #287)
  * Exception thrown due to unassigned "local_dir" variable. (Issue
    [#377])
- changes from version 1.6.0:
  * Report E731 for lambda assignment. (Issue #277)
  * Report E704 for one-liner def instead of E701.
    Do not report this error in the default configuration. (Issue #277)
  * Replace codes E111, E112 and E113 with codes E114, E115 and E116
    for bad indentation of comments. (Issue #274)
  * Report E266 instead of E265 when the block comment starts with
    multiple "#". (Issue #270)
  * Report E402 for import statements not at the top of the file. (Issue #264)
  * Do not enforce whitespaces around "**" operator. (Issue #292)
  * Strip whitespace from around paths during normalization. (Issue #339 / #343)
  * Update "--format" documentation. (Issue #198 / Pull Request #310)
  * Add ".tox/" to default excludes. (Issue #335)
  * Do not report E121 or E126 in the default configuration. (Issues #256 / #316)
  * Allow spaces around the equals sign in an annotated function. (Issue #357)
  * Allow trailing backslash if in an inline comment. (Issue #374)
  * If "--config" is used, only that configuration is processed. Otherwise,
    merge the user and local configurations are merged. (Issue #368 / #369)
  * Don't crash if Checker.build_tokens_line() returns None. (Issue #306)
  * Don't crash if os.path.expanduser() throws an ImportError. (Issue #297)
  * Missing space around keyword parameter equal not always reported, E251.
    (Issue #323)
  * Fix false positive E711/E712/E713. (Issues #330 and #336)
  * Do not skip physical checks if the newline is escaped. (Issue #319)
  * Flush sys.stdout to avoid race conditions with printing. See flake8 bug:
    https://gitlab.com/pycqa/flake8/issues/17 for more details. (Issue #363)
* Thu Jan 22 2015 arun@gmx.de
- specfile:
  * update copyright year
  * remove python(abi) requirement
* Thu Jul 10 2014 toddrme2178@gmail.com
- update to 1.5.7:
  * Skip the traceback on "Broken pipe" signal. (Issue #275)
  * Do not exit when an option in ``setup.cfg`` or ``tox.ini``
    is not recognized.
  * Check the last line even if it does not end with a newline. (Issue #286)
  * Always open files in universal newlines mode in Python 2. (Issue #288)
* Thu May 15 2014 toddrme2178@gmail.com
- Use setuptools instead of distribute (upstreams merged)
* Fri May  9 2014 toddrme2178@gmail.com
- update to 1.5.6:
  * Check the last line even if it has no end-of-line.
- update to 1.5.5:
  * Fix regression with E22 checks and inline comments.
- update to 1.5.4:
  * Fix negative offset with E303 before a multi-line docstring.
  * Fix wrong offset computation when error is on the last char
    of a physical line. (Issue #268)
  * Distribute a universal wheel file.
  * Report correct line number for E303 with comments. (Issue #60)
  * Do not allow newline after parameter equal. (Issue #252)
  * Fix line number reported for multi-line strings. (Issue #220)
  * Fix false positive E121/E126 with multi-line strings. (Issue #265)
  * Fix E501 not detected in comments with Python 2.5.
  * Fix caret position with ``--show-source`` when line contains tabs.
  * Fix a crash with E125 on multi-line strings. (Issue #263)
  * Report E129 instead of E125 for visually indented line with same
    indent as next logical line.  (Issue #126)
  * Report E265 for space before block comment. (Issue #190)
  * Allow long lines in multiline strings and comments if they cannot
    be wrapped. (Issue #224).
  * Optionally disable physical line checks inside multiline strings,
    using ``# noqa``. (Issue #242)
  * Change text for E121 to report "continuation line under-indented
    for hanging indent" instead of indentation not being a
    multiple of 4.
  * Report E131 instead of E121 / E126 if the hanging indent is not
    consistent within the same continuation block.  It helps when
    error E121 or E126 is in the ``ignore`` list.
  * Report E126 instead of E121 when the continuation line is hanging
    with extra indentation, even if indentation is not a multiple of 4.
  * Allow the checkers to report errors on empty files. (Issue #240)
  * Fix ignoring too many checks when ``--select`` is used with codes
    declared in a flake8 extension. (Issue #216)
  * Fix regression with multiple brackets. (Issue #214)
  * Fix ``StyleGuide`` to parse the local configuration if the
    keyword argument ``paths`` is specified. (Issue #246)
  * Fix a false positive E124 for hanging indent. (Issue #254)
  * Fix a false positive E126 with embedded colon. (Issue #144)
  * Fix a false positive E126 when indenting with tabs. (Issue #204)
  * Fix behaviour when ``exclude`` is in the configuration file and
    the current directory is not the project directory. (Issue #247)
  * The logical checks can return ``None`` instead of an empty iterator.
    (Issue #250)
  * Do not report multiple E101 if only the first indentation starts
    with a tab. (Issue #237)
  * Fix a rare false positive W602. (Issue #34)
- remove no-tox-test.diff
* Tue Oct 15 2013 toddrme2178@gmail.com
- Upodate to version 1.4.6
  * Honor ``# noqa`` for errors E711 and E712. (Issue #180)
  * When both a ``tox.ini`` and a ``setup.cfg`` are present in the project
    directory, merge their contents.  The ``tox.ini`` file takes
    precedence (same as before). (Issue #182)
  * Give priority to ``--select`` over ``--ignore``. (Issue #188)
  * Compare full path when excluding a file. (Issue #186)
  * Correctly report other E12 errors when E123 is ignored. (Issue #103)
  * New option ``--hang-closing`` to switch to the alternative style of
    closing bracket indentation for hanging indent.  Add error E133 for
    closing bracket which is missing indentation. (Issue #103)
  * Accept both styles of closing bracket indentation for hanging indent.
    Do not report error E123 in the default configuration. (Issue #103)
  * Do not crash when running AST checks and the document contains null bytes.
    (Issue #184)
  * Fix false positive E261/E262 when the file contains a BOM. (Issue #193)
  * Fix E701, E702 and E703 not detected sometimes. (Issue #196)
  * Fix E122 not detected in some cases. (Issue #201 and #208)
  * Fix false positive E121 with multiple brackets. (Issue #203)
* Sat May 18 2013 dmueller@suse.com
- udpate to 1.4.5:
  * When no path is specified, do not try to read from stdin.
  * Do not require ``setuptools`` in setup.py.  It works around an issue
  with ``pip`` and Python 3. (Issue #172)
  * Add ``__pycache__`` to the ignore list.
  * Change misleading message for E251. (Issue #171)
  * Do not report false E302 when the source file has a coding cookie or a
  comment on the first line. (Issue #174)
  * Reorganize the tests and add tests for the API and for the command line
  usage and options. (Issues #161 and #162)
  * Ignore all checks which are not explicitly selected when ``select`` is
  passed to the ``StyleGuide`` constructor
* Sun Feb 24 2013 p.drouand@gmail.com
- Update to version 1.4.4:
  * Report E227 or E228 instead of E225 for whitespace around bitwise,
    shift or modulo operators. (Issue #166)
  * Change the message for E226 to make clear that it is about arithmetic operators.
  * Fix a false positive E128 for continuation line indentation with tabs.
  * Fix regression with the --diff option. (Issue #169)
  * Fix the TestReport class to print the unexpected warnings and errors.
* Fri Feb 22 2013 p.drouand@gmail.com
- Update to version 1.4.3:
  * Hide the --doctest and --testsuite options when installed.
  * Fix crash with AST checkers when the syntax is invalid. (Issue #160)
  * Read from standard input if no path is specified.
  * Initiate a graceful shutdown on Control+C.
  * Allow to change the checker_class for the StyleGuide.
* Mon Jan 28 2013 dmueller@suse.com
- Update to version 1.4.1:
  * Report E703 instead of E702 for the trailing semicolon. (Issue #117)
  * Report E226 instead of E225 for optional white space around common
  operators (``*``, ``**``, ``/``, ``+`` and ``-``).  This new error
  code is ignored in the default configuration because PEP 8 recommends
  to "use your own judgement". (Issue #96)
  * Lines with a ``# nopep8`` at the end will not issue errors on line
  length E501 or continuation line indentation E12*. (Issue #27)
  * Fix AssertionError when the source file contains an invalid line
  ending ``"\r\r\n"``. (Issue #119)
  * Read the ``[pep8]`` section of ``tox.ini`` or ``setup.cfg`` if present.
  * Add the Sphinx-based documentation, and publish it
  * Fix false positive E124 and E128 with comments. (Issue #100)
  * Fix error on stdin when running with bpython. (Issue #101)
  * Fix false positive E401. (Issue #104)
  * Report E231 for nested dictionary in list. (Issue #142)
  * Catch E271 at the beginning of the line. (Issue #133)
  * Fix false positive E126 for multi-line comments. (Issue #138)
  * Fix false positive E221 when operator is preceded by a comma. (Issue #135)
  * Fix ``--diff`` failing on one-line hunk. (Issue #137)
  * Fix the ``--exclude`` switch for directory paths. (Issue #111)
  * Use ``-`` filename to read from standard input. (Issue #128)
  * Fix regression with continuation line checker. (Issue #98)
  * Add E902 for IO errors. (Issue #87)
  * Fix false positive for E121, and missed E124. (Issue #92)
  * Allow ``verbose`` in the configuration file. (Issue #91)
  * Show the enforced ``max-line-length`` in the error message. (Issue #86)
* Thu Nov 22 2012 toddrme2178@gmail.com
- Removed openSUSE 11.4 spec file workarounds
* Thu Sep  6 2012 toddrme2178@gmail.com
- Restore BuildRequires: python3  This package depends on hash
  algorithms that are only available if python3 is installed,
  python3-devel will not pull them in.  Building will fail if
  BuildRequires: python3 is removed.
* Tue Jun 26 2012 saschpe@suse.de
- Update to version 1.3.1:
  + Explain which configuration options are expected. Accept and recommend
    the options names with hyphen instead of underscore. (Issue #82)
  + Do not read the user configuration when used as a module (except if
    config_file=True is passed to the StyleGuide constructor).
  + Fix wrong or missing cases for the E12 series.
  + Fix cases where E122 was missed. (Issue #81)
- Changes from version 1.3.0:
  + Remove global configuration and refactor the library around a StyleGuide
    class; add the ability to configure various reporters. (Issue #35 and #66)
  + Read user configuration from ~/.config/pep8 and local configuration from
    ./.pep8. (Issue #22)
  + Fix E502 for backslash embedded in multi-line string. (Issue #68)
  + Fix E225 for Python 3 iterable unpacking (PEP 3132). (Issue #72)
  + Enable the new checkers from the E12 series in the default configuration.
  + Suggest less error-prone alternatives for E712 errors.
  + Rewrite checkers to run faster (E22, E251, E27).
  + Fixed a crash when parsed code is invalid (too many closing brackets).
  + Fix E127 and E128 for continuation line indentation. (Issue #74)
  + New option --format to customize the error format. (Issue #23)
  + New option --diff to check only modified code. The unified diff is read
    from STDIN. Example: hg diff | pep8 --diff (Issue #39)
  + Correctly report the count of failures and set the exit code to 1 when
    the --doctest or the --testsuite fails.
  + Correctly detect the encoding in Python 3. (Issue #69)
  + Drop support for Python 2.3, 2.4 and 3.0. (Issue #78)
- Don't package empty TODO.txt
- No need to BuildRequire: python3, python3-devel is enough
- Require: python3 => %%pyver
* Thu Jun 14 2012 toddrme2178@gmail.com
- Fix building on openSUSE <= 12.2
* Wed Jun  6 2012 saschpe@suse.de
- Update to version 1.2:
  * Add E121 through E128 for continuation line indentation.  These
    checks are disabled by default.  If you want to force all checks,
    use switch ``--select=E,W``.  Patch by Sam Vilain. (Issue #64)
  * Add E721 for direct type comparisons. (Issue #47)
  * Add E711 and E712 for comparisons to singletons. (Issue #46)
  * Fix spurious E225 and E701 for function annotations. (Issue #29)
  * Add E502 for explicit line join between brackets.
  * Fix E901 when printing source with ``--show-source``.
  * Report all errors for each checker, instead of reporting only the
    first occurence for each line.
  * Option ``--show-pep8`` implies ``--first``.
* Wed May 23 2012 toddrme2178@gmail.com
- Add python 3 package
- Clean up spec file
- Update to release 1.1
  * Add E901 for syntax errors. (Issues #63 and #30)
  * Add E271, E272, E273 and E274 for extraneous whitespace around
    keywords. (Issue #57)
  * Add ``tox.ini`` configuration file for tests. (Issue #61)
  * Add ``.travis.yml`` configuration file for continuous integration.
    (Issue #62)
